@@ -100,7 +100,8 @@ class EloquaRestClient(object):
         depth='minimal',
         count=1000,
         page=0,
-        order_by=''
+        order_by='',
+        search=''
     ):
         url = self.rest_url + '/assets/' + asset_type
         return self.get(
@@ -108,7 +109,8 @@ class EloquaRestClient(object):
             depth=depth,
             count=count,
             page=page,
-            orderBy=order_by)
+            orderBy=order_by,
+            search=search)
 
     def get(self, url, headers=None, **queryparams):
         if not headers:
